OC.L10N.register(
    "settings",
    {
    "Sharing" : "Dela",
    "External Storage" : "Extern lagring",
    "Cron" : "Cron",
    "Log" : "Logg",
    "Updates" : "Uppdateringar",
    "Authentication error" : "Fel vid autentisering",
    "Your full name has been changed." : "Hela ditt namn har ändrats",
    "Unable to change full name" : "Kunde inte ändra hela namnet",
    "Couldn't remove app." : "Kunde inte ta bort applikationen.",
    "Language changed" : "Språk ändrades",
    "Invalid request" : "Ogiltig begäran",
    "Admins can't remove themself from the admin group" : "Administratörer kan inte ta bort sig själva från admingruppen",
    "Unable to add user to group %s" : "Kan inte lägga till användare i gruppen %s",
    "Unable to remove user from group %s" : "Kan inte radera användare från gruppen %s",
    "Couldn't update app." : "Kunde inte uppdatera appen.",
    "Wrong password" : "Fel lösenord",
    "No user supplied" : "Ingen användare angiven",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Ange ett återställningslösenord för administratören. Annars kommer all användardata förloras",
    "Wrong admin recovery password. Please check the password and try again." : "Felaktigt återställningslösenord för administratör. Kolla lösenordet och prova igen.",
    "Unable to change password" : "Kunde inte ändra lösenord",
    "Enabled" : "Aktiverad",
    "Not enabled" : "Inte aktiverad",
    "Group already exists." : "Gruppen finns redan.",
    "Unable to add group." : "Lyckades inte lägga till grupp.",
    "Unable to delete group." : "Lyckades inte radera grupp.",
    "log-level out of allowed range" : "logg-nivå utanför tillåtet område",
    "Saved" : "Sparad",
    "test email settings" : "testa e-post inställningar",
    "Email sent" : "E-post skickat",
    "You need to set your user email before being able to send test emails." : "Du behöver ställa in din användares e-postadress före du kan skicka test e-post.",
    "Invalid mail address" : "Ogiltig e-postadress",
    "Unable to create user." : "Kan inte skapa användare.",
    "Your %s account was created" : "Ditt %s konto skapades",
    "Unable to delete user." : "Kan inte radera användare.",
    "Forbidden" : "Förbjuden",
    "Invalid user" : "Ogiltig användare",
    "Unable to change mail address" : "Kan inte ändra e-postadress",
    "Email saved" : "E-post sparad",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Är du verkligen säker på att du vill lägga till \"{domain}\" som en trusted domian?",
    "Add trusted domain" : "Lägg till betrodd domän",
    "Sending..." : "Skickar ...",
    "All" : "Alla",
    "Update to %s" : "Uppdatera till %s",
    "Please wait...." : "Var god vänta ...",
    "Error while disabling app" : "Fel vid inaktivering av app",
    "Disable" : "Deaktivera",
    "Enable" : "Aktivera",
    "Error while enabling app" : "Fel vid aktivering av app",
    "Updating...." : "Uppdaterar ...",
    "Error while updating app" : "Fel uppstod vid uppdatering av appen",
    "Updated" : "Uppdaterad",
    "Uninstalling ...." : "Avinstallerar ...",
    "Error while uninstalling app" : "Ett fel inträffade när applikatonen avinstallerades",
    "Uninstall" : "Avinstallera",
    "Select a profile picture" : "Välj en profilbild",
    "Very weak password" : "Väldigt svagt lösenord",
    "Weak password" : "Svagt lösenord",
    "So-so password" : "Okej lösenord",
    "Good password" : "Bra lösenord",
    "Strong password" : "Starkt lösenord",
    "Valid until {date}" : "Giltig t.o.m. {date}",
    "Delete" : "Radera",
    "Groups" : "Grupper",
    "Unable to delete {objName}" : "Kunde inte radera {objName}",
    "Error creating group" : "Fel vid skapande av grupp",
    "A valid group name must be provided" : "Ett giltigt gruppnamn måste anges",
    "deleted {groupName}" : "raderade {groupName} ",
    "undo" : "ångra",
    "no group" : "ingen grupp",
    "never" : "aldrig",
    "deleted {userName}" : "raderade {userName}",
    "add group" : "lägg till grupp",
    "A valid username must be provided" : "Ett giltigt användarnamn måste anges",
    "Error creating user" : "Fel vid skapande av användare",
    "A valid password must be provided" : "Ett giltigt lösenord måste anges",
    "A valid email must be provided" : "En giltig e-postadress måste anges",
    "__language_name__" : "__language_name__",
    "SSL root certificates" : "SSL rotcertifikat",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Allting (allvarliga fel, fel, varningar, info, debug)",
    "Info, warnings, errors and fatal issues" : "Info, varningar och allvarliga fel",
    "Warnings, errors and fatal issues" : "Varningar, fel och allvarliga fel",
    "Errors and fatal issues" : "Fel och allvarliga fel",
    "Fatal issues only" : "Endast allvarliga fel",
    "None" : "Ingen",
    "Login" : "Logga in",
    "Plain" : "Enkel",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Lär-bara konfigureringen har blivit aktiv. Detta förhindrar att några konfigureringar kan sättas via web-gränssnittet.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP är tydligen inställd för att rensa inline doc block. Detta kommer att göra flera kärnapplikationer otillgängliga.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Detta orsakas troligtvis av en cache/accelerator som t ex Zend OPchache eller eAccelerator.",
    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Din server använder Microsoft Windows. Vi rekommenderar starkt Linux för en optimal användarerfarenhet.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP-modulen 'fileinfo' saknas. Vi rekommenderar starkt att aktivera den här modulen för att kunna upptäcka korrekt mime-typ.",
    "System locale can not be set to a one which supports UTF-8." : "Systemspråk kan inte ställas in till ett som stödjer UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Detta betyder att där kan komma att uppstå problem med vissa tecken i filnamn.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Vi rekommenderar starkt att installera de nödvändiga paketen på ditt system för att stödja en av följande språkversioner: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Om din installation inte installerades på roten av domänen och använder system cron så kan det uppstå problem med URL-genereringen. För att undvika dessa problem, var vänlig sätt \"overwrite.cli.url\"-inställningen i din config.php-fil till webbrotsökvägen av din installation (Föreslagen: \"%s\")",
    "Allow apps to use the Share API" : "Tillåt applikationer att använda delat API",
    "Allow users to share via link" : "Tillåt användare att dela via länk",
    "Enforce password protection" : "Tillämpa lösenordskydd",
    "Allow public uploads" : "Tillåt offentlig uppladdning",
    "Allow users to send mail notification for shared files" : "Tillåt användare att skicka mailnotifieringar för delade filer",
    "Set default expiration date" : "Ställ in standardutgångsdatum",
    "Expire after " : "Förfaller efter",
    "days" : "dagar",
    "Enforce expiration date" : "Tillämpa förfallodatum",
    "Allow resharing" : "Tillåt vidaredelning",
    "Restrict users to only share with users in their groups" : "Begränsa användare till att enbart kunna dela med användare i deras grupper",
    "Allow users to send mail notification for shared files to other users" : "Tillåt användare att skicka mejlnotifiering för delade filer till andra användare",
    "Exclude groups from sharing" : "Exkludera grupp från att dela",
    "These groups will still be able to receive shares, but not to initiate them." : "Dessa grupper kommer fortfarande kunna ta emot delningar, men inte skapa delningar.",
    "Cron was not executed yet!" : "Cron kördes inte ännu!",
    "Execute one task with each page loaded" : "Exekvera en uppgift vid varje sidladdning",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php är registrerad som en webcron service att ropa på cron.php varje 15 minuter över http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Använd systemets cron-tjänst för att anropa cron.php var 15:e minut.",
    "This is used for sending out notifications." : "Detta används för att skicka ut notifieringar.",
    "Send mode" : "Sändningsläge",
    "Encryption" : "Kryptering",
    "From address" : "Från adress",
    "mail" : "mail",
    "Authentication method" : "Autentiseringsmetod",
    "Authentication required" : "Autentisering krävs",
    "Server address" : "Serveradress",
    "Port" : "Port",
    "Credentials" : "Inloggningsuppgifter",
    "SMTP Username" : "SMTP-användarnamn",
    "SMTP Password" : "SMTP-lösenord",
    "Store credentials" : "Lagra inloggningsuppgifter",
    "Test email settings" : "Testa e-postinställningar",
    "Send email" : "Skicka e-post",
    "Log level" : "Nivå på loggning",
    "Download logfile" : "Ladda ner loggfil",
    "More" : "Mer",
    "Less" : "Mindre",
    "Version" : "Version",
    "by" : "av",
    "licensed" : "licensierad",
    "Documentation:" : "Dokumentation:",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Denna applikation kan inte installeras då följande beroenden inte är uppfyllda: %s",
    "Enable only for specific groups" : "Aktivera endast för specifika grupper",
    "Uninstall App" : "Avinstallera applikation",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hej där,<br><br>vill bara informera dig om att du nu har ett %s konto.<br><br>Ditt användarnamn: %s<br>Accessa det genom: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Ha de fint!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hej där,\n\nvill bara informera dig om att du nu har ett %s konto.\n\nDitt användarnamn: %s\nAccessa det genom: %s\n",
    "Forum" : "Forum",
    "Get the apps to sync your files" : "Skaffa apparna för att synkronisera dina filer",
    "Desktop client" : "Skrivbordsklient",
    "Android app" : "Android-app",
    "iOS app" : "iOS-app",
    "Show First Run Wizard again" : "Visa Första uppstarts-guiden igen",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Du har använt <strong>%s</strong> av tillgängliga <strong>%s</strong>",
    "Password" : "Lösenord",
    "Unable to change your password" : "Kunde inte ändra ditt lösenord",
    "Current password" : "Nuvarande lösenord",
    "New password" : "Nytt lösenord",
    "Change password" : "Ändra lösenord",
    "No display name set" : "Inget visningsnamn angivet",
    "Email" : "E-post",
    "Your email address" : "Din e-postadress",
    "Fill in an email address to enable password recovery and receive notifications" : "Fyll i en e-postadress för att aktivera återställning av lösenord och mottagande av notifieringar",
    "No email address set" : "Ingen e-postadress angiven",
    "Profile picture" : "Profilbild",
    "Upload new" : "Ladda upp ny",
    "Select new from Files" : "Välj ny från filer",
    "Remove image" : "Radera bild",
    "Your avatar is provided by your original account." : "Din avatar tillhandahålls av ditt ursprungliga konto.",
    "Cancel" : "Avbryt",
    "Choose as profile image" : "Välj som profilbild",
    "Language" : "Språk",
    "Help translate" : "Hjälp att översätta",
    "Common Name" : "Vanligt namn",
    "Valid until" : "Giltigt till",
    "Issued By" : "Utfärdat av",
    "Valid until %s" : "Giltigt till %s",
    "Show storage location" : "Visa lagringsplats",
    "Show last log in" : "Visa senaste inloggning",
    "Show user backend" : "Visa användar-back-end",
    "Send email to new user" : "Skicka e-post till ny användare",
    "Show email address" : "Visa e-postadress",
    "Username" : "Användarnamn",
    "E-Mail" : "E-post",
    "Create" : "Skapa",
    "Admin Recovery Password" : "Admin-återställningslösenord",
    "Enter the recovery password in order to recover the users files during password change" : "Ange återställningslösenordet för att återställa användarnas filer vid lösenordsbyte",
    "Add Group" : "Lägg till Grupp",
    "Group" : "Grupp",
    "Everyone" : "Alla",
    "Admins" : "Administratörer",
    "Default Quota" : "Förvald datakvot",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Var god skriv in lagringskvot (ex: \"512MB\" eller \"12 GB\")",
    "Unlimited" : "Obegränsad",
    "Other" : "Annat",
    "Full Name" : "Hela namnet",
    "Group Admin for" : "Gruppadministratör för",
    "Quota" : "Kvot",
    "Storage Location" : "Lagringsplats",
    "User Backend" : "Användar-back-end",
    "Last Login" : "Senaste inloggning",
    "change full name" : "ändra hela namnet",
    "set new password" : "ange nytt lösenord",
    "change email address" : "ändra e-postadress",
    "Default" : "Förvald"
},
"nplurals=2; plural=(n != 1);");
